# dpytools
Toolset to speed up developing discord bots using discord.py

<hr>

## Status of the project

Early development. As such its expected to be unstable and unsuited for production.

## Components

**Module** | **Functions** | **Notes**
--- | --- | --- 
menus | arrows  | Dispays a menu made from passed Embeds with navigation by reaction.
.| confirm | Returns the user reaction to confirm or deny a passed message.
embeds | paginate_to_embeds | Paginates a long text into a list of embeds.
parsers| parse_time | Parses strings with the format "2h15m" to a timedelta object.
owner_cog | - | collection of useful commands for the bot owner.
More to come... 

<hr>

# Contributing
Feel free to make a pull request.